//
//  AppDelegate.m
//  ColorfulWebKit
//
//  Created by Craig Hockenberry on 5/3/16.
//  Copyright © 2016 The Iconfactory. All rights reserved.
//

#import "AppDelegate.h"

#import <WebKit/WebKit.h>

@interface AppDelegate ()

@property (weak) IBOutlet NSWindow *window;
@property (weak) IBOutlet WebView *webView;
@property (weak) IBOutlet NSTextField *statusTextField;

@end

@implementation AppDelegate

- (void)applicationDidFinishLaunching:(NSNotification *)aNotification
{
	// load the index.html file and graphics from this project's "Colorful Web Resources" folder
	NSURL *URL = [[NSBundle mainBundle] URLForResource:@"index" withExtension:@"html"];
	[self.webView.mainFrame loadRequest:[NSURLRequest requestWithURL:URL]];
}

- (BOOL)applicationShouldTerminateAfterLastWindowClosed:(NSApplication *)application
{
	return YES;
}

- (IBAction)changeBackground:(id)sender
{
	// clicking each toolbar item sends a changeBackground action with a tag to indicate the selection
	NSToolbarItem *toolbarItem = (NSToolbarItem *)sender;
	NSInteger backgroundSelection = toolbarItem.tag;
	
	// pass the background selection to the web page by calling the setBackground JavaScript function
	[self.webView.windowScriptObject callWebScriptMethod:@"setBackground" withArguments:@[ @(backgroundSelection) ]];

	// query the background setting on the web page by calling more JavaScript functions
	NSNumber *background = (NSNumber *)[self.webView.windowScriptObject callWebScriptMethod:@"background" withArguments:nil];
	NSString *backgroundColor = (NSString *)[self.webView.windowScriptObject callWebScriptMethod:@"backgroundColor" withArguments:nil];

	// make the status text field's background match the web content by using the sRGB color space
	NSColor *color = nil;
	switch (backgroundSelection) {
		case 1:
		default:
			color = [NSColor colorWithSRGBRed:(255.0/255.0) green:(0.0/255.0) blue:(0.0/255.0) alpha:1.0];
			break;
			
		case 2:
			color = [NSColor colorWithSRGBRed:(102.0/255.0) green:(0.0/255.0) blue:(204.0/255.0) alpha:1.0];
			break;
			
		case 3:
			color = [NSColor colorWithSRGBRed:(123.0/255.0) green:(45.0/255.0) blue:(67.0/255.0) alpha:1.0];
			break;
			
		case 4:
			color = [NSColor colorWithSRGBRed:(12.0/255.0) green:(34.0/255.0) blue:(56.0/255.0) alpha:1.0];
			break;
			
	}
	self.statusTextField.backgroundColor = color;
	self.statusTextField.stringValue = [NSString stringWithFormat:@"\nThe selection changed to %@ and the sRGB background color now matches '%@'", background, backgroundColor];
}

@end
